<?php
/*
 * Copyright (c) 2013, webvariants GbR, http://www.webvariants.de
 *
 * This file is released under the terms of the MIT license. You can find the
 * complete text in the attached LICENSE file or online at:
 *
 * http://www.opensource.org/licenses/mit-license.php
 */

/**
 * Encrypted datatype
 *
 * To use this datatype, your project needs to have phpSec installed via
 * Composer. Add it to your project's composer.json:
 *
 * {
 *    "require": {
 *       "phpsec/phpsec": "0.6.*"
 *    }
 * }
 *
 * NOTE: Make sure that you use a CURRENT release of phpsec (even if you had
 * to update this datatype), in order to avoid known security problems and
 * stuff. And never ever use non-stable versions.
 *
 * In future Devutils releases, this might be a fixed requirement.
 */
class WV_Datatype_Encrypted extends WV_Datatype_Blob {
	protected function serializer($value, array $params, $mode) {
		$passphrase = $params['passphrase'];

		if (!empty($params['is_base64'])) {
			$passphrase = base64_decode($passphrase);
		}
		elseif (!empty($params['is_callback'])) {
			$passphrase = call_user_func($passphrase, $params);
		}

		// phpSec 0.5 and 0.6 have different APIs
		$phpsec05 = !class_exists('phpSec\Core');

		switch ($mode) {
			case 'encode':
				if ($phpsec05) {
					return phpSec\Crypt\Crypto::encrypt($value, $passphrase);
				}
				else {
					$psl    = new phpSec\Core();
					$crypto = $psl['crypt/crypto'];

					return $crypto->encrypt($value, $passphrase);
				}

			case 'decode':
				if ($value === '' || $value === null) return null;

				if ($phpsec05) {
					return phpSec\Crypt\Crypto::decrypt($value, $passphrase);
				}
				else {
					$psl    = new phpSec\Core();
					$crypto = $psl['crypt/crypto'];

					return $crypto->decrypt($value, $passphrase);
				}

			default:
				throw new InvalidArgumentException('Unknown mode '.$mode.' given.');
		}
	}
}
