<?php
/*
 * Copyright (c) 2013, webvariants GbR, http://www.webvariants.de
 *
 * This file is released under the terms of the MIT license. You can find the
 * complete text in the attached LICENSE file or online at:
 *
 * http://www.opensource.org/licenses/mit-license.php
 */

class WV8_Settings_Provider {
	protected $manager;

	public function __construct(WV8_Settings_Manager $manager) {
		$this->manager = $manager;
	}

	public function getAllSettings() {
		return $this->manager->getSettings();
	}

	public function getPages($with_hidden = true) {
		$result = array();
		$all    = $this->getAllSettings();

		foreach ($all as $settings) {
			foreach ($settings as $setting) {
				/* @var $setting WV8_Setting */
				if ($with_hidden || !$setting->getData('hidden')) {
					$result[$setting->getPageID()] = $setting->getPagename();
				}
			}
		}

		return $result;
	}

	public function getGroups($namespace = null, $page = null, $with_hidden = true) {
		$result = array();
		$all    = $this->getAllSettings();

		foreach ($all as $ns => $settings) {
			// if filtering by namespace, it's easy to skip this sublist
			if ($namespace !== null && $ns !== $namespace) continue;

			foreach ($settings as $setting) {
				/* @var $setting WV8_Setting */
				if (!($with_hidden || !$setting->getData('hidden'))) {
					continue;
				}
				// filter by page
				if ($page !== null && !$setting->isPage($page)) continue;

				$result[$setting->getGroupID()] = $setting->getGroup();
			}
		}

		return $result;
	}

	public function getSettings($namespace = null, $page = null, $group = null) {
		$result = array();
		$all    = $this->getAllSettings();

		foreach ($all as $ns => $settings) {
			// if filtering by namespace, it's easy to skip this sublist
			if ($namespace !== null && $ns !== $namespace) continue;

			foreach ($settings as $name => $setting) {
				// filter by page
				if ($page !== null && !$setting->isPage($page)) continue;

				// filter by group
				if ($group !== null && !$setting->isGroup($group)) continue;

				$key          = $ns.'/'.$name;
				$result[$key] = $setting;
			}
		}

		return $result;
	}

	public function exists($namespace, $name) {
		$all = $this->getAllSettings();
		return isset($all[$namespace][$name]);
	}

	/**
	 * get setting instance
	 *
	 * @param  string $namespace
	 * @param  string $name
	 * @return WV8_Setting
	 */
	public function getSetting($namespace, $name) {
		$all = $this->getAllSettings();

		if (!$this->exists($namespace, $name)) {
			throw new WV8_Exception('Setting "'.$namespace.'/'.$name.'" does not exist.');
		}

		return $all[$namespace][$name];
	}

	/**
	 * get setting instance by its ID
	 *
	 * @param  string $settingID
	 * @return WV8_Setting
	 */
	public function getSettingByID($settingID) {
		$all = $this->getAllSettings();

		foreach ($all as $ns => $settings) {
			foreach ($settings as $name => $setting) {
				if ($setting->getID() === $settingID) {
					return $setting;
				}
			}
		}

		return null;
	}
}
