<?php
/*
 * Copyright (c) 2013, webvariants GbR, http://www.webvariants.de
 *
 * This file is released under the terms of the MIT license. You can find the
 * complete text in the attached LICENSE file or online at:
 *
 * http://www.opensource.org/licenses/mit-license.php
 */

namespace wv\metainfo\Listener;

use sly_Model_Category;
use wv\metainfo\Metainfo;
use wv\metainfo\Authorisation;

class Category extends Backend {
	/**
	 * Handler for SLY_CAT_FORM_EDIT
	 *
	 * Adds the metainfo fields to the form
	 *
	 * @param  string $subjectHTML  form html
	 * @param  array  $params       die von Sally übergebenen Parameter
	 * @return string               das Subject inkl. des Formulars
	 */
	public function onCategoryEditForm($subjectHTML, array $params) {
		if (!Authorisation::canEdit() && !Authorisation::canView()) {
			return $subjectHTML;
		}

		// Zugewiesene Daten ermitteln
		$canEdit      = Authorisation::canEdit();
		$category     = $params['category'];
		$container    = Metainfo::getContainer();
		$propService  = $container['metainfo-service-property'];
		$valueService = $container['metainfo-service-value'];

		$assignedData   = $valueService->findCategoryData($category);
		$availableInfos = $propService->findCategoryProperties();
		$dataToDisplay  = $this->getInfosToDisplay($availableInfos, $assignedData, $availableInfos);

		// no infos? return subject
		if (empty($availableInfos)) {
			return $subjectHTML;
		}

		ob_start();
		require _WV2_PATH.'templates/categories/meta_frontend.phtml';
		return $subjectHTML.ob_get_clean();
	}

	/**
	 * Handler for SLY_CAT_ADDED
	 *
	 * Fügt der neuen Kategorie alle vorhandenen Metainformationen
	 * hinzu.
	 *
	 * @param sly_Model_Category $category
	 * @param array              $params    die von Sally übergebenen Parameter
	 */
	public static function onCategoryAdded(sly_Model_Category $category, array $params) {
		$container	  = Metainfo::getContainer();
		$propService  = $container['metainfo-service-property'];
		$valueService = $container['metainfo-service-value'];
		$metainfos	  = $propService->findCategoryProperties();

		foreach ($metainfos as $name => $metainfo) {
			$metainfos[$name] = $metainfo->getDefault();
			$valueService->insertCategory($category, $name, $metainfo->getDefault());
		}

		$article = \sly_Util_Article::findById($category->getId(), $category->getClang(), 0);
		$container['metainfo-listener-article']->onArticleAdded($article);
	}

	/**
	 * Handler for SLY_CAT_UPDATED
	 *
	 * Serialisiert das Frontend-Formular.
	 *
	 * @param array $params  die von Sally übergebenen Parameter
	 */
	public function onCategoryUpdated(sly_Model_Category $category, array $params) {
		if (!Authorisation::canEdit()) {
			return;
		}

		$container = Metainfo::getContainer();
		$errors    = $container['metainfo-serializer']->processCategoryForm($category);

		if (is_array($errors)) {
			// NO wv\metainfo\Exception, Sally wouldn't catch it!
			throw new \sly_Exception($this->getErrorText($errors, Metainfo::TYPE_CATEGORY));
		}
	}

	/**
	 * Handler for SLY_CAT_DELETED
	 *
	 * deletes all data of the category and the associated article
	 *
	 * @param sly_Model_Category $category  the deleted category
	 * @param array              $params    additionally parameters
	 */
	public function onCategoryDeleted(sly_Model_Category $category, array $params) {
		Metainfo::clearDataCache();
	}
}
