/*
 * Copyright (c) 2013, webvariants GbR, http://www.webvariants.de
 *
 * This file is released under the terms of the MIT license. You can find the
 * complete text in the attached LICENSE file or online at:
 *
 * http://www.opensource.org/licenses/mit-license.php
 */

jQuery(function($) {
	'use strict';

	var addToData = function(container, path, value) {
		var
			len     = path.length,
			isArray = len <= 2 && path[len-1] === '',
			node    = path[0];

		if (len === 1) {
			if (isArray) {
				container.push(value);
			}
			else {
				container[node] = value;
			}
		}
		else {
			if (!(node in container)) {
				container[node] = isArray ? [] : {};
			}

			addToData(container[node], path.slice(1), value);
		}
	};

	var prepareKey = function(key) {
		var first = key.indexOf('['), path = [], matches, i, len, match;

		if (first === -1) {
			return [key];
		}

		// 'foo[bar][]' => '[foo][bar][]'
		key     = '[' + key.substring(0, first) + ']' + key.substring(first);
		matches = key.match(/\[(.*?)\]/g); // ['[foo]', '[bar]', '[]']
		len     = matches.length;

		for (i = 0; i < len; ++i) {
			match = matches[i];
			path.push(match.substring(1, match.length - 1));
		}

		return path; // ['foo', 'bar', '']
	};

	var serializeForm = function(form) {
		var data = form.serializeArray(), result = {}, len = data.length, i, element;

		for (i = 0; i < len; ++i) {
			element = data[i];
			addToData(result, prepareKey(element.name), element.value);
		}

		return result;
	};

	$('#wv42rbac-role-form').on('submit', function() {
		var
			form = $(this),
			data = serializeForm(form),
			json = JSON.stringify(data);

		// keep the user experience of submitting a form by creating a dummy form to submit

		$('<form>')
			.attr('method', 'post')
			.attr('action', form.attr('action'))
			.append($('<input type="hidden" name="json" />').val(json))
			.appendTo($('body'))
			.submit();

		return false;
	});
});
