<?php
/*
 * Copyright (c) 2013, webvariants GbR, http://www.webvariants.de
 *
 * This file is released under the terms of the MIT license. You can find the
 * complete text in the attached LICENSE file or online at:
 *
 * http://www.opensource.org/licenses/mit-license.php
 */

namespace wv\realurl2\Listener;

use sly_Core;
use sly_Model_Category;
use sly_Util_Language;
use wv\realurl2\Util;

/**
 * Sally-Eventlistener
 *
 * Diese Klasse sammelt zu einem Großteil nur Listener, um den URL-Cache immer
 * aktuell zu halten. Für gewöhnlich will niemand diese Methoden direkt
 * aufrufen.
 *
 * @author Christoph
 * @since  forever
 */
class Categories extends Base {
	/**
	 * SLY_CAT_ADDED: Kategorie wurde hinzugefügt
	 */
	public function catAdded(sly_Model_Category $cat) {
		$articleListener = $this->container['realurl2-listener-articles'];
		$articleListener->artAdded($cat);
	}

	/**
	 * SLY_CAT_FORM_EDIT: Fragment-Formular erzeugen
	 *
	 * @param  array $params  die von Sally übergebenen Parameter
	 * @return string         das übergebene Subject mit dem angehängten Formularteil
	 */
	public function catFormEdit($html, array $params) {
		$category   = $params['category'];
		$categoryID = $category->getId();
		$clang      = $category->getClang();
		$fragment   = Util::getFragment($category);
		$skipped    = Util::isSkipped($category);

		ob_start();
		include _WV24_PATH.'views/category.phtml';
		return $html.ob_get_clean();
	}

	/**
	 * SLY_CAT_UPDATED: Kategorie wurde umbenannt
	 */
	public function catUpdated(sly_Model_Category $category) {
		$id      = $category->getId();
		$clang   = $category->getClang();
		$rev     = $category->getRevision();
		$request = $this->container['sly-request'];

		// API-call-based events should not overwrite database data since no form was submitted
		if ($request->post->has('realurl2_fragment')) {
			$fragment = $this->getFragment();
			$skipped  = $request->post('realurl2_skip', 'boolean', false) ? 1 : 0;
			$db       = $this->container['sly-persistence'];

			// update database (set fragment and skip on all revisions, because categories
			// are not versioned and this makes it much easier to display the correct fragment
			// in the start article's contentmeta form).
			$db->update('article', array('wv24_fragment' => $fragment, 'wv24_skip' => $skipped), array('id' => $id, 'clang' => $clang));
		}

		// do nothing if the 'start category' was changed
		if ($id === sly_Core::getSiteStartArticleId()) {
			return;
		}

		if (Util::hasSiteStartArticle()) {
			$this->rebuildTree($id, $clang);
		}
	}

	/**
	 * SLY_CAT_MOVED
	 */
	public function catMoved($catID, array $params) {
		if (!Util::hasSiteStartArticle()) return;

		$clang = $params['clang'];

		// kill all outdated URLs
		$storage = $this->getStorage();
		$storage->clearByPath(RealURL2::URL_NAMESPACE, '%|'.$catID.'|%');
		$storage->clearByArticle($catID);

		// re-generate the tree
		foreach (sly_Util_Language::findAll(true) as $clang) {
			$this->rebuildTree($catID, $clang, null, false);
		}
	}
}
